import pickle
from flask import Flask, render_template, request
import base64
from io import BytesIO
from PIL import Image
import numpy as np
from tensorflow.keras.models import load_model

app = Flask(__name__)

# Load the model
loaded_model = load_model('/Users/sayantankundu/Downloads/resnet_exp4.h5')

# Load class labels
with open('/Users/sayantankundu/Downloads/class_labels.pkl', 'rb') as file:
    class_labels = pickle.load(file)

# Preprocess the uploaded image
def preprocess_image(image):
    img = Image.open(image)
    img = img.resize((224, 224))
    img = np.array(img) / 255.0
    return img

# Predict the label
def predict_label(image):
    img_array = preprocess_image(image)
    prediction = loaded_model.predict(np.expand_dims(img_array, axis=0))
    predicted_label = class_labels[np.argmax(prediction)]
    return predicted_label

@app.route('/', methods=['GET', 'POST'])
def index():
    predictions = []
    if request.method == 'POST':
        if 'reset' in request.form:
            return render_template('index.html', predictions=[])
        
        file_list = request.files.getlist('file')
        for file in file_list:
            img = file.read()
            img_str = base64.b64encode(img).decode('utf-8')
            predicted_label = predict_label(BytesIO(img))
            predictions.append({'image': img_str, 'label': predicted_label})
        return render_template('index.html', predictions=predictions)
    return render_template('index.html', predictions=[])

if __name__ == '__main__':
    app.run(debug=True)
